@@ -109,32 +109,52 @@ terminal_client_append_create_instance_options (GVariantBuilder *builder,
  */
 void
 terminal_client_append_exec_options (GVariantBuilder *builder,
+                                     gboolean         pass_environment,
                                      const char      *working_directory,
                                      PassFdElement   *fd_array,
                                      gsize            fd_array_len,
                                      gboolean         shell)
 {
-  gs_strfreev char **envv;
+  if (pass_environment) {
+    gs_strfreev char **envv;
 
-  envv = g_get_environ ();
-  envv = g_environ_unsetenv (envv, "COLORTERM");
-  envv = g_environ_unsetenv (envv, "COLUMNS");
-  envv = g_environ_unsetenv (envv, "DESKTOP_STARTUP_ID");
-  envv = g_environ_unsetenv (envv, "GIO_LAUNCHED_DESKTOP_FILE_PID");
-  envv = g_environ_unsetenv (envv, "GIO_LAUNCHED_DESKTOP_FILE");
-  envv = g_environ_unsetenv (envv, "GNOME_DESKTOP_ICON");
-  envv = g_environ_unsetenv (envv, "LINES");
-  envv = g_environ_unsetenv (envv, "NOTIFY_SOCKET");
-  envv = g_environ_unsetenv (envv, "PWD");
-  envv = g_environ_unsetenv (envv, "TERM");
-  envv = g_environ_unsetenv (envv, "VTE_VERSION");
-  envv = g_environ_unsetenv (envv, "WINDOWID");
-  envv = g_environ_unsetenv (envv, TERMINAL_ENV_SERVICE_NAME);
-  envv = g_environ_unsetenv (envv, TERMINAL_ENV_SCREEN);
+    envv = g_get_environ ();
+    envv = g_environ_unsetenv (envv, "COLORTERM");
+    envv = g_environ_unsetenv (envv, "COLUMNS");
+    envv = g_environ_unsetenv (envv, "DESKTOP_STARTUP_ID");
+    envv = g_environ_unsetenv (envv, "EXIT_CODE");
+    envv = g_environ_unsetenv (envv, "EXIT_STATUS");
+    envv = g_environ_unsetenv (envv, "GIO_LAUNCHED_DESKTOP_FILE");
+    envv = g_environ_unsetenv (envv, "GIO_LAUNCHED_DESKTOP_FILE_PID");
+    envv = g_environ_unsetenv (envv, "GNOME_DESKTOP_ICON");
+    envv = g_environ_unsetenv (envv, "INVOCATION_ID");
+    envv = g_environ_unsetenv (envv, "JOURNAL_STREAM");
+    envv = g_environ_unsetenv (envv, "LINES");
+    envv = g_environ_unsetenv (envv, "LISTEN_FDNAMES");
+    envv = g_environ_unsetenv (envv, "LISTEN_FDS");
+    envv = g_environ_unsetenv (envv, "LISTEN_PID");
+    envv = g_environ_unsetenv (envv, "MAINPID");
+    envv = g_environ_unsetenv (envv, "MANAGERPID");
+    envv = g_environ_unsetenv (envv, "NOTIFY_SOCKET");
+    envv = g_environ_unsetenv (envv, "NOTIFY_SOCKET");
+    envv = g_environ_unsetenv (envv, "PIDFILE");
+    envv = g_environ_unsetenv (envv, "PWD");
+    envv = g_environ_unsetenv (envv, "REMOTE_ADDR");
+    envv = g_environ_unsetenv (envv, "REMOTE_PORT");
+    envv = g_environ_unsetenv (envv, "SERVICE_RESULT");
+    envv = g_environ_unsetenv (envv, "TERM");
+    envv = g_environ_unsetenv (envv, "VTE_VERSION");
+    envv = g_environ_unsetenv (envv, "WATCHDOG_PID");
+    envv = g_environ_unsetenv (envv, "WATCHDOG_USEC");
+    envv = g_environ_unsetenv (envv, "WINDOWID");
 
-  g_variant_builder_add (builder, "{sv}",
-                         "environ",
-                         g_variant_new_bytestring_array ((const char * const *) envv, -1));
+    envv = g_environ_unsetenv (envv, TERMINAL_ENV_SERVICE_NAME);
+    envv = g_environ_unsetenv (envv, TERMINAL_ENV_SCREEN);
+
+    g_variant_builder_add (builder, "{sv}",
+                           "environ",
+                           g_variant_new_bytestring_array ((const char * const *) envv, -1));
+  }
 
   if (working_directory)
     g_variant_builder_add (builder, "{sv}",
